@@ -14,4 +14,6 @@ plot_mesh_res.py
 
 from mesh_generator.bin.call_fortran_mesh import create_fortran_mesh
 from mesh_generator.bin.mesh_header_template import write_mesh_header
-from mesh_generator.bin.shell_command import run_shell_command
\ No newline at end of file
+from mesh_generator.bin.shell_command import run_shell_command
+from mesh_generator.bin.tmp_mas_template import write_tmp_mas_file
+from mesh_generator.bin.plot_mesh_res import plot_mesh_res
\ No newline at end of file
